# esi-ruby

EsiClient - the Ruby gem for the EVE Swagger Interface

An OpenAPI for EVE Online

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.5.3
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build esi-ruby.gemspec
```

Then either install the gem locally:

```shell
gem install ./esi-ruby-1.0.0.gem
```
(for development, run `gem install --dev ./esi-ruby-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'esi-ruby', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/tarisatram/esi-ruby, then add the following in the Gemfile:

    gem 'esi-ruby', :git => 'https://github.com/tarisatram/esi-ruby.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'esi-ruby'

api_instance = EsiClient::AllianceApi.new

opts = { 
  datasource: "tranquility", # String | The server name you would like data from
  user_agent: "user_agent_example", # String | Client identifier, takes precedence over headers
  x_user_agent: "x_user_agent_example" # String | Client identifier, takes precedence over User-Agent
}

begin
  #List all alliances
  result = api_instance.get_alliances(opts)
  p result
rescue EsiClient::ApiError => e
  puts "Exception when calling AllianceApi->get_alliances: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://esi.tech.ccp.is/latest*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*EsiClient::AllianceApi* | [**get_alliances**](docs/AllianceApi.md#get_alliances) | **GET** /alliances/ | List all alliances
*EsiClient::AllianceApi* | [**get_alliances_alliance_id**](docs/AllianceApi.md#get_alliances_alliance_id) | **GET** /alliances/{alliance_id}/ | Get alliance information
*EsiClient::AllianceApi* | [**get_alliances_alliance_id_corporations**](docs/AllianceApi.md#get_alliances_alliance_id_corporations) | **GET** /alliances/{alliance_id}/corporations/ | List alliance's corporations
*EsiClient::AllianceApi* | [**get_alliances_alliance_id_icons**](docs/AllianceApi.md#get_alliances_alliance_id_icons) | **GET** /alliances/{alliance_id}/icons/ | Get alliance icon
*EsiClient::AllianceApi* | [**get_alliances_names**](docs/AllianceApi.md#get_alliances_names) | **GET** /alliances/names/ | Get alliance names
*EsiClient::AssetsApi* | [**get_characters_character_id_assets**](docs/AssetsApi.md#get_characters_character_id_assets) | **GET** /characters/{character_id}/assets/ | Get character assets
*EsiClient::BookmarksApi* | [**get_characters_character_id_bookmarks**](docs/BookmarksApi.md#get_characters_character_id_bookmarks) | **GET** /characters/{character_id}/bookmarks/ | List bookmarks
*EsiClient::BookmarksApi* | [**get_characters_character_id_bookmarks_folders**](docs/BookmarksApi.md#get_characters_character_id_bookmarks_folders) | **GET** /characters/{character_id}/bookmarks/folders/ | List bookmark folders
*EsiClient::CalendarApi* | [**get_characters_character_id_calendar**](docs/CalendarApi.md#get_characters_character_id_calendar) | **GET** /characters/{character_id}/calendar/ | List calendar event summaries
*EsiClient::CalendarApi* | [**get_characters_character_id_calendar_event_id**](docs/CalendarApi.md#get_characters_character_id_calendar_event_id) | **GET** /characters/{character_id}/calendar/{event_id}/ | Get an event
*EsiClient::CalendarApi* | [**put_characters_character_id_calendar_event_id**](docs/CalendarApi.md#put_characters_character_id_calendar_event_id) | **PUT** /characters/{character_id}/calendar/{event_id}/ | Respond to an event
*EsiClient::CharacterApi* | [**get_characters_character_id**](docs/CharacterApi.md#get_characters_character_id) | **GET** /characters/{character_id}/ | Get character's public information
*EsiClient::CharacterApi* | [**get_characters_character_id_agents_research**](docs/CharacterApi.md#get_characters_character_id_agents_research) | **GET** /characters/{character_id}/agents_research/ | Get agents research
*EsiClient::CharacterApi* | [**get_characters_character_id_blueprints**](docs/CharacterApi.md#get_characters_character_id_blueprints) | **GET** /characters/{character_id}/blueprints/ | Get blueprints
*EsiClient::CharacterApi* | [**get_characters_character_id_chat_channels**](docs/CharacterApi.md#get_characters_character_id_chat_channels) | **GET** /characters/{character_id}/chat_channels/ | Get chat channels
*EsiClient::CharacterApi* | [**get_characters_character_id_corporationhistory**](docs/CharacterApi.md#get_characters_character_id_corporationhistory) | **GET** /characters/{character_id}/corporationhistory/ | Get corporation history
*EsiClient::CharacterApi* | [**get_characters_character_id_medals**](docs/CharacterApi.md#get_characters_character_id_medals) | **GET** /characters/{character_id}/medals/ | Get medals
*EsiClient::CharacterApi* | [**get_characters_character_id_portrait**](docs/CharacterApi.md#get_characters_character_id_portrait) | **GET** /characters/{character_id}/portrait/ | Get character portraits
*EsiClient::CharacterApi* | [**get_characters_character_id_roles**](docs/CharacterApi.md#get_characters_character_id_roles) | **GET** /characters/{character_id}/roles/ | Get character corporation roles
*EsiClient::CharacterApi* | [**get_characters_character_id_standings**](docs/CharacterApi.md#get_characters_character_id_standings) | **GET** /characters/{character_id}/standings/ | Get standings
*EsiClient::CharacterApi* | [**get_characters_names**](docs/CharacterApi.md#get_characters_names) | **GET** /characters/names/ | Get character names
*EsiClient::CharacterApi* | [**post_characters_affiliation**](docs/CharacterApi.md#post_characters_affiliation) | **POST** /characters/affiliation/ | Character affiliation
*EsiClient::CharacterApi* | [**post_characters_character_id_cspa**](docs/CharacterApi.md#post_characters_character_id_cspa) | **POST** /characters/{character_id}/cspa/ | Calculate a CSPA charge cost
*EsiClient::ClonesApi* | [**get_characters_character_id_clones**](docs/ClonesApi.md#get_characters_character_id_clones) | **GET** /characters/{character_id}/clones/ | Get clones
*EsiClient::ContactsApi* | [**delete_characters_character_id_contacts**](docs/ContactsApi.md#delete_characters_character_id_contacts) | **DELETE** /characters/{character_id}/contacts/ | Delete contacts
*EsiClient::ContactsApi* | [**get_characters_character_id_contacts**](docs/ContactsApi.md#get_characters_character_id_contacts) | **GET** /characters/{character_id}/contacts/ | Get contacts
*EsiClient::ContactsApi* | [**get_characters_character_id_contacts_labels**](docs/ContactsApi.md#get_characters_character_id_contacts_labels) | **GET** /characters/{character_id}/contacts/labels/ | Get contact labels
*EsiClient::ContactsApi* | [**post_characters_character_id_contacts**](docs/ContactsApi.md#post_characters_character_id_contacts) | **POST** /characters/{character_id}/contacts/ | Add contacts
*EsiClient::ContactsApi* | [**put_characters_character_id_contacts**](docs/ContactsApi.md#put_characters_character_id_contacts) | **PUT** /characters/{character_id}/contacts/ | Edit contacts
*EsiClient::ContractsApi* | [**get_characters_character_id_contracts**](docs/ContractsApi.md#get_characters_character_id_contracts) | **GET** /characters/{character_id}/contracts/ | Get contracts
*EsiClient::ContractsApi* | [**get_characters_character_id_contracts_contract_id_bids**](docs/ContractsApi.md#get_characters_character_id_contracts_contract_id_bids) | **GET** /characters/{character_id}/contracts/{contract_id}/bids/ | Get contract bids
*EsiClient::ContractsApi* | [**get_characters_character_id_contracts_contract_id_items**](docs/ContractsApi.md#get_characters_character_id_contracts_contract_id_items) | **GET** /characters/{character_id}/contracts/{contract_id}/items/ | Get contract items
*EsiClient::CorporationApi* | [**get_corporations_corporation_id**](docs/CorporationApi.md#get_corporations_corporation_id) | **GET** /corporations/{corporation_id}/ | Get corporation information
*EsiClient::CorporationApi* | [**get_corporations_corporation_id_alliancehistory**](docs/CorporationApi.md#get_corporations_corporation_id_alliancehistory) | **GET** /corporations/{corporation_id}/alliancehistory/ | Get alliance history
*EsiClient::CorporationApi* | [**get_corporations_corporation_id_icons**](docs/CorporationApi.md#get_corporations_corporation_id_icons) | **GET** /corporations/{corporation_id}/icons/ | Get corporation icon
*EsiClient::CorporationApi* | [**get_corporations_corporation_id_members**](docs/CorporationApi.md#get_corporations_corporation_id_members) | **GET** /corporations/{corporation_id}/members/ | Get corporation members
*EsiClient::CorporationApi* | [**get_corporations_corporation_id_roles**](docs/CorporationApi.md#get_corporations_corporation_id_roles) | **GET** /corporations/{corporation_id}/roles/ | Get corporation member roles
*EsiClient::CorporationApi* | [**get_corporations_corporation_id_structures**](docs/CorporationApi.md#get_corporations_corporation_id_structures) | **GET** /corporations/{corporation_id}/structures/ | Get corporation structures
*EsiClient::CorporationApi* | [**get_corporations_names**](docs/CorporationApi.md#get_corporations_names) | **GET** /corporations/names/ | Get corporation names
*EsiClient::CorporationApi* | [**get_corporations_npccorps**](docs/CorporationApi.md#get_corporations_npccorps) | **GET** /corporations/npccorps/ | Get npc corporations
*EsiClient::CorporationApi* | [**put_corporations_corporation_id_structures_structure_id**](docs/CorporationApi.md#put_corporations_corporation_id_structures_structure_id) | **PUT** /corporations/{corporation_id}/structures/{structure_id}/ | Update structure vulnerability schedule
*EsiClient::DogmaApi* | [**get_dogma_attributes**](docs/DogmaApi.md#get_dogma_attributes) | **GET** /dogma/attributes/ | Get attributes
*EsiClient::DogmaApi* | [**get_dogma_attributes_attribute_id**](docs/DogmaApi.md#get_dogma_attributes_attribute_id) | **GET** /dogma/attributes/{attribute_id}/ | Get attribute information
*EsiClient::DogmaApi* | [**get_dogma_effects**](docs/DogmaApi.md#get_dogma_effects) | **GET** /dogma/effects/ | Get effects
*EsiClient::DogmaApi* | [**get_dogma_effects_effect_id**](docs/DogmaApi.md#get_dogma_effects_effect_id) | **GET** /dogma/effects/{effect_id}/ | Get effect information
*EsiClient::FittingsApi* | [**delete_characters_character_id_fittings_fitting_id**](docs/FittingsApi.md#delete_characters_character_id_fittings_fitting_id) | **DELETE** /characters/{character_id}/fittings/{fitting_id}/ | Delete fitting
*EsiClient::FittingsApi* | [**get_characters_character_id_fittings**](docs/FittingsApi.md#get_characters_character_id_fittings) | **GET** /characters/{character_id}/fittings/ | Get fittings
*EsiClient::FittingsApi* | [**post_characters_character_id_fittings**](docs/FittingsApi.md#post_characters_character_id_fittings) | **POST** /characters/{character_id}/fittings/ | Create fitting
*EsiClient::FleetsApi* | [**delete_fleets_fleet_id_members_member_id**](docs/FleetsApi.md#delete_fleets_fleet_id_members_member_id) | **DELETE** /fleets/{fleet_id}/members/{member_id}/ | Kick fleet member
*EsiClient::FleetsApi* | [**delete_fleets_fleet_id_squads_squad_id**](docs/FleetsApi.md#delete_fleets_fleet_id_squads_squad_id) | **DELETE** /fleets/{fleet_id}/squads/{squad_id}/ | Delete fleet squad
*EsiClient::FleetsApi* | [**delete_fleets_fleet_id_wings_wing_id**](docs/FleetsApi.md#delete_fleets_fleet_id_wings_wing_id) | **DELETE** /fleets/{fleet_id}/wings/{wing_id}/ | Delete fleet wing
*EsiClient::FleetsApi* | [**get_fleets_fleet_id**](docs/FleetsApi.md#get_fleets_fleet_id) | **GET** /fleets/{fleet_id}/ | Get fleet information
*EsiClient::FleetsApi* | [**get_fleets_fleet_id_members**](docs/FleetsApi.md#get_fleets_fleet_id_members) | **GET** /fleets/{fleet_id}/members/ | Get fleet members
*EsiClient::FleetsApi* | [**get_fleets_fleet_id_wings**](docs/FleetsApi.md#get_fleets_fleet_id_wings) | **GET** /fleets/{fleet_id}/wings/ | Get fleet wings
*EsiClient::FleetsApi* | [**post_fleets_fleet_id_members**](docs/FleetsApi.md#post_fleets_fleet_id_members) | **POST** /fleets/{fleet_id}/members/ | Create fleet invitation
*EsiClient::FleetsApi* | [**post_fleets_fleet_id_wings**](docs/FleetsApi.md#post_fleets_fleet_id_wings) | **POST** /fleets/{fleet_id}/wings/ | Create fleet wing
*EsiClient::FleetsApi* | [**post_fleets_fleet_id_wings_wing_id_squads**](docs/FleetsApi.md#post_fleets_fleet_id_wings_wing_id_squads) | **POST** /fleets/{fleet_id}/wings/{wing_id}/squads/ | Create fleet squad
*EsiClient::FleetsApi* | [**put_fleets_fleet_id**](docs/FleetsApi.md#put_fleets_fleet_id) | **PUT** /fleets/{fleet_id}/ | Update fleet
*EsiClient::FleetsApi* | [**put_fleets_fleet_id_members_member_id**](docs/FleetsApi.md#put_fleets_fleet_id_members_member_id) | **PUT** /fleets/{fleet_id}/members/{member_id}/ | Move fleet member
*EsiClient::FleetsApi* | [**put_fleets_fleet_id_squads_squad_id**](docs/FleetsApi.md#put_fleets_fleet_id_squads_squad_id) | **PUT** /fleets/{fleet_id}/squads/{squad_id}/ | Rename fleet squad
*EsiClient::FleetsApi* | [**put_fleets_fleet_id_wings_wing_id**](docs/FleetsApi.md#put_fleets_fleet_id_wings_wing_id) | **PUT** /fleets/{fleet_id}/wings/{wing_id}/ | Rename fleet wing
*EsiClient::IncursionsApi* | [**get_incursions**](docs/IncursionsApi.md#get_incursions) | **GET** /incursions/ | List incursions
*EsiClient::IndustryApi* | [**get_characters_character_id_industry_jobs**](docs/IndustryApi.md#get_characters_character_id_industry_jobs) | **GET** /characters/{character_id}/industry/jobs/ | List character industry jobs
*EsiClient::IndustryApi* | [**get_industry_facilities**](docs/IndustryApi.md#get_industry_facilities) | **GET** /industry/facilities/ | List industry facilities
*EsiClient::IndustryApi* | [**get_industry_systems**](docs/IndustryApi.md#get_industry_systems) | **GET** /industry/systems/ | List solar system cost indices
*EsiClient::InsuranceApi* | [**get_insurance_prices**](docs/InsuranceApi.md#get_insurance_prices) | **GET** /insurance/prices/ | List insurance levels
*EsiClient::KillmailsApi* | [**get_characters_character_id_killmails_recent**](docs/KillmailsApi.md#get_characters_character_id_killmails_recent) | **GET** /characters/{character_id}/killmails/recent/ | List kills and losses
*EsiClient::KillmailsApi* | [**get_killmails_killmail_id_killmail_hash**](docs/KillmailsApi.md#get_killmails_killmail_id_killmail_hash) | **GET** /killmails/{killmail_id}/{killmail_hash}/ | Get a single killmail
*EsiClient::LocationApi* | [**get_characters_character_id_location**](docs/LocationApi.md#get_characters_character_id_location) | **GET** /characters/{character_id}/location/ | Get character location
*EsiClient::LocationApi* | [**get_characters_character_id_online**](docs/LocationApi.md#get_characters_character_id_online) | **GET** /characters/{character_id}/online/ | Get character online
*EsiClient::LocationApi* | [**get_characters_character_id_ship**](docs/LocationApi.md#get_characters_character_id_ship) | **GET** /characters/{character_id}/ship/ | Get current ship
*EsiClient::LoyaltyApi* | [**get_characters_character_id_loyalty_points**](docs/LoyaltyApi.md#get_characters_character_id_loyalty_points) | **GET** /characters/{character_id}/loyalty/points/ | Get loyalty points
*EsiClient::LoyaltyApi* | [**get_loyalty_stores_corporation_id_offers**](docs/LoyaltyApi.md#get_loyalty_stores_corporation_id_offers) | **GET** /loyalty/stores/{corporation_id}/offers/ | List loyalty store offers
*EsiClient::MailApi* | [**delete_characters_character_id_mail_labels_label_id**](docs/MailApi.md#delete_characters_character_id_mail_labels_label_id) | **DELETE** /characters/{character_id}/mail/labels/{label_id}/ | Delete a mail label
*EsiClient::MailApi* | [**delete_characters_character_id_mail_mail_id**](docs/MailApi.md#delete_characters_character_id_mail_mail_id) | **DELETE** /characters/{character_id}/mail/{mail_id}/ | Delete a mail
*EsiClient::MailApi* | [**get_characters_character_id_mail**](docs/MailApi.md#get_characters_character_id_mail) | **GET** /characters/{character_id}/mail/ | Return mail headers
*EsiClient::MailApi* | [**get_characters_character_id_mail_labels**](docs/MailApi.md#get_characters_character_id_mail_labels) | **GET** /characters/{character_id}/mail/labels/ | Get mail labels and unread counts
*EsiClient::MailApi* | [**get_characters_character_id_mail_lists**](docs/MailApi.md#get_characters_character_id_mail_lists) | **GET** /characters/{character_id}/mail/lists/ | Return mailing list subscriptions
*EsiClient::MailApi* | [**get_characters_character_id_mail_mail_id**](docs/MailApi.md#get_characters_character_id_mail_mail_id) | **GET** /characters/{character_id}/mail/{mail_id}/ | Return a mail
*EsiClient::MailApi* | [**post_characters_character_id_mail**](docs/MailApi.md#post_characters_character_id_mail) | **POST** /characters/{character_id}/mail/ | Send a new mail
*EsiClient::MailApi* | [**post_characters_character_id_mail_labels**](docs/MailApi.md#post_characters_character_id_mail_labels) | **POST** /characters/{character_id}/mail/labels/ | Create a mail label
*EsiClient::MailApi* | [**put_characters_character_id_mail_mail_id**](docs/MailApi.md#put_characters_character_id_mail_mail_id) | **PUT** /characters/{character_id}/mail/{mail_id}/ | Update metadata about a mail
*EsiClient::MarketApi* | [**get_characters_character_id_orders**](docs/MarketApi.md#get_characters_character_id_orders) | **GET** /characters/{character_id}/orders/ | List orders from a character
*EsiClient::MarketApi* | [**get_markets_groups**](docs/MarketApi.md#get_markets_groups) | **GET** /markets/groups/ | Get item groups
*EsiClient::MarketApi* | [**get_markets_groups_market_group_id**](docs/MarketApi.md#get_markets_groups_market_group_id) | **GET** /markets/groups/{market_group_id}/ | Get item group information
*EsiClient::MarketApi* | [**get_markets_prices**](docs/MarketApi.md#get_markets_prices) | **GET** /markets/prices/ | List market prices
*EsiClient::MarketApi* | [**get_markets_region_id_history**](docs/MarketApi.md#get_markets_region_id_history) | **GET** /markets/{region_id}/history/ | List historical market statistics in a region
*EsiClient::MarketApi* | [**get_markets_region_id_orders**](docs/MarketApi.md#get_markets_region_id_orders) | **GET** /markets/{region_id}/orders/ | List orders in a region
*EsiClient::MarketApi* | [**get_markets_structures_structure_id**](docs/MarketApi.md#get_markets_structures_structure_id) | **GET** /markets/structures/{structure_id}/ | List orders in a structure
*EsiClient::OpportunitiesApi* | [**get_characters_character_id_opportunities**](docs/OpportunitiesApi.md#get_characters_character_id_opportunities) | **GET** /characters/{character_id}/opportunities/ | Get a character's completed tasks
*EsiClient::OpportunitiesApi* | [**get_opportunities_groups**](docs/OpportunitiesApi.md#get_opportunities_groups) | **GET** /opportunities/groups/ | Get opportunities groups
*EsiClient::OpportunitiesApi* | [**get_opportunities_groups_group_id**](docs/OpportunitiesApi.md#get_opportunities_groups_group_id) | **GET** /opportunities/groups/{group_id}/ | Get opportunities group
*EsiClient::OpportunitiesApi* | [**get_opportunities_tasks**](docs/OpportunitiesApi.md#get_opportunities_tasks) | **GET** /opportunities/tasks/ | Get opportunities tasks
*EsiClient::OpportunitiesApi* | [**get_opportunities_tasks_task_id**](docs/OpportunitiesApi.md#get_opportunities_tasks_task_id) | **GET** /opportunities/tasks/{task_id}/ | Get opportunities task
*EsiClient::PlanetaryInteractionApi* | [**get_characters_character_id_planets**](docs/PlanetaryInteractionApi.md#get_characters_character_id_planets) | **GET** /characters/{character_id}/planets/ | Get colonies
*EsiClient::PlanetaryInteractionApi* | [**get_characters_character_id_planets_planet_id**](docs/PlanetaryInteractionApi.md#get_characters_character_id_planets_planet_id) | **GET** /characters/{character_id}/planets/{planet_id}/ | Get colony layout
*EsiClient::PlanetaryInteractionApi* | [**get_universe_schematics_schematic_id**](docs/PlanetaryInteractionApi.md#get_universe_schematics_schematic_id) | **GET** /universe/schematics/{schematic_id}/ | Get schematic information
*EsiClient::RoutesApi* | [**get_route_origin_destination**](docs/RoutesApi.md#get_route_origin_destination) | **GET** /route/{origin}/{destination}/ | Get route
*EsiClient::SearchApi* | [**get_characters_character_id_search**](docs/SearchApi.md#get_characters_character_id_search) | **GET** /characters/{character_id}/search/ | Search on a string
*EsiClient::SearchApi* | [**get_search**](docs/SearchApi.md#get_search) | **GET** /search/ | Search on a string
*EsiClient::SkillsApi* | [**get_characters_character_id_attributes**](docs/SkillsApi.md#get_characters_character_id_attributes) | **GET** /characters/{character_id}/attributes/ | Get character attributes
*EsiClient::SkillsApi* | [**get_characters_character_id_skillqueue**](docs/SkillsApi.md#get_characters_character_id_skillqueue) | **GET** /characters/{character_id}/skillqueue/ | Get character's skill queue
*EsiClient::SkillsApi* | [**get_characters_character_id_skills**](docs/SkillsApi.md#get_characters_character_id_skills) | **GET** /characters/{character_id}/skills/ | Get character skills
*EsiClient::SovereigntyApi* | [**get_sovereignty_campaigns**](docs/SovereigntyApi.md#get_sovereignty_campaigns) | **GET** /sovereignty/campaigns/ | List sovereignty campaigns
*EsiClient::SovereigntyApi* | [**get_sovereignty_map**](docs/SovereigntyApi.md#get_sovereignty_map) | **GET** /sovereignty/map/ | List sovereignty of systems
*EsiClient::SovereigntyApi* | [**get_sovereignty_structures**](docs/SovereigntyApi.md#get_sovereignty_structures) | **GET** /sovereignty/structures/ | List sovereignty structures
*EsiClient::StatusApi* | [**get_status**](docs/StatusApi.md#get_status) | **GET** /status/ | Retrieve the uptime and player counts
*EsiClient::UniverseApi* | [**get_universe_bloodlines**](docs/UniverseApi.md#get_universe_bloodlines) | **GET** /universe/bloodlines/ | Get bloodlines
*EsiClient::UniverseApi* | [**get_universe_categories**](docs/UniverseApi.md#get_universe_categories) | **GET** /universe/categories/ | Get item categories
*EsiClient::UniverseApi* | [**get_universe_categories_category_id**](docs/UniverseApi.md#get_universe_categories_category_id) | **GET** /universe/categories/{category_id}/ | Get item category information
*EsiClient::UniverseApi* | [**get_universe_constellations**](docs/UniverseApi.md#get_universe_constellations) | **GET** /universe/constellations/ | Get constellations
*EsiClient::UniverseApi* | [**get_universe_constellations_constellation_id**](docs/UniverseApi.md#get_universe_constellations_constellation_id) | **GET** /universe/constellations/{constellation_id}/ | Get constellation information
*EsiClient::UniverseApi* | [**get_universe_factions**](docs/UniverseApi.md#get_universe_factions) | **GET** /universe/factions/ | Get factions
*EsiClient::UniverseApi* | [**get_universe_graphics**](docs/UniverseApi.md#get_universe_graphics) | **GET** /universe/graphics/ | Get graphics
*EsiClient::UniverseApi* | [**get_universe_graphics_graphic_id**](docs/UniverseApi.md#get_universe_graphics_graphic_id) | **GET** /universe/graphics/{graphic_id}/ | Get graphic information
*EsiClient::UniverseApi* | [**get_universe_groups**](docs/UniverseApi.md#get_universe_groups) | **GET** /universe/groups/ | Get item groups
*EsiClient::UniverseApi* | [**get_universe_groups_group_id**](docs/UniverseApi.md#get_universe_groups_group_id) | **GET** /universe/groups/{group_id}/ | Get item group information
*EsiClient::UniverseApi* | [**get_universe_moons_moon_id**](docs/UniverseApi.md#get_universe_moons_moon_id) | **GET** /universe/moons/{moon_id}/ | Get moon information
*EsiClient::UniverseApi* | [**get_universe_planets_planet_id**](docs/UniverseApi.md#get_universe_planets_planet_id) | **GET** /universe/planets/{planet_id}/ | Get planet information
*EsiClient::UniverseApi* | [**get_universe_races**](docs/UniverseApi.md#get_universe_races) | **GET** /universe/races/ | Get character races
*EsiClient::UniverseApi* | [**get_universe_regions**](docs/UniverseApi.md#get_universe_regions) | **GET** /universe/regions/ | Get regions
*EsiClient::UniverseApi* | [**get_universe_regions_region_id**](docs/UniverseApi.md#get_universe_regions_region_id) | **GET** /universe/regions/{region_id}/ | Get region information
*EsiClient::UniverseApi* | [**get_universe_stargates_stargate_id**](docs/UniverseApi.md#get_universe_stargates_stargate_id) | **GET** /universe/stargates/{stargate_id}/ | Get stargate information
*EsiClient::UniverseApi* | [**get_universe_stations_station_id**](docs/UniverseApi.md#get_universe_stations_station_id) | **GET** /universe/stations/{station_id}/ | Get station information
*EsiClient::UniverseApi* | [**get_universe_structures**](docs/UniverseApi.md#get_universe_structures) | **GET** /universe/structures/ | List all public structures
*EsiClient::UniverseApi* | [**get_universe_structures_structure_id**](docs/UniverseApi.md#get_universe_structures_structure_id) | **GET** /universe/structures/{structure_id}/ | Get structure information
*EsiClient::UniverseApi* | [**get_universe_system_jumps**](docs/UniverseApi.md#get_universe_system_jumps) | **GET** /universe/system_jumps/ | Get system jumps
*EsiClient::UniverseApi* | [**get_universe_system_kills**](docs/UniverseApi.md#get_universe_system_kills) | **GET** /universe/system_kills/ | Get system kills
*EsiClient::UniverseApi* | [**get_universe_systems**](docs/UniverseApi.md#get_universe_systems) | **GET** /universe/systems/ | Get solar systems
*EsiClient::UniverseApi* | [**get_universe_systems_system_id**](docs/UniverseApi.md#get_universe_systems_system_id) | **GET** /universe/systems/{system_id}/ | Get solar system information
*EsiClient::UniverseApi* | [**get_universe_types**](docs/UniverseApi.md#get_universe_types) | **GET** /universe/types/ | Get types
*EsiClient::UniverseApi* | [**get_universe_types_type_id**](docs/UniverseApi.md#get_universe_types_type_id) | **GET** /universe/types/{type_id}/ | Get type information
*EsiClient::UniverseApi* | [**post_universe_names**](docs/UniverseApi.md#post_universe_names) | **POST** /universe/names/ | Get names and categories for a set of ID's
*EsiClient::UserInterfaceApi* | [**post_ui_autopilot_waypoint**](docs/UserInterfaceApi.md#post_ui_autopilot_waypoint) | **POST** /ui/autopilot/waypoint/ | Set Autopilot Waypoint
*EsiClient::UserInterfaceApi* | [**post_ui_openwindow_contract**](docs/UserInterfaceApi.md#post_ui_openwindow_contract) | **POST** /ui/openwindow/contract/ | Open Contract Window
*EsiClient::UserInterfaceApi* | [**post_ui_openwindow_information**](docs/UserInterfaceApi.md#post_ui_openwindow_information) | **POST** /ui/openwindow/information/ | Open Information Window
*EsiClient::UserInterfaceApi* | [**post_ui_openwindow_marketdetails**](docs/UserInterfaceApi.md#post_ui_openwindow_marketdetails) | **POST** /ui/openwindow/marketdetails/ | Open Market Details
*EsiClient::UserInterfaceApi* | [**post_ui_openwindow_newmail**](docs/UserInterfaceApi.md#post_ui_openwindow_newmail) | **POST** /ui/openwindow/newmail/ | Open New Mail Window
*EsiClient::WalletApi* | [**get_characters_character_id_wallet**](docs/WalletApi.md#get_characters_character_id_wallet) | **GET** /characters/{character_id}/wallet/ | Get a character's wallet balance
*EsiClient::WalletApi* | [**get_characters_character_id_wallet_journal**](docs/WalletApi.md#get_characters_character_id_wallet_journal) | **GET** /characters/{character_id}/wallet/journal/ | Get character wallet journal
*EsiClient::WalletApi* | [**get_characters_character_id_wallet_transactions**](docs/WalletApi.md#get_characters_character_id_wallet_transactions) | **GET** /characters/{character_id}/wallet/transactions/ | Get wallet transactions
*EsiClient::WalletApi* | [**get_characters_character_id_wallets**](docs/WalletApi.md#get_characters_character_id_wallets) | **GET** /characters/{character_id}/wallets/ | List wallets and balances
*EsiClient::WalletApi* | [**get_characters_character_id_wallets_journal**](docs/WalletApi.md#get_characters_character_id_wallets_journal) | **GET** /characters/{character_id}/wallets/journal/ | Get character wallet journal
*EsiClient::WarsApi* | [**get_wars**](docs/WarsApi.md#get_wars) | **GET** /wars/ | List wars
*EsiClient::WarsApi* | [**get_wars_war_id**](docs/WarsApi.md#get_wars_war_id) | **GET** /wars/{war_id}/ | Get war information
*EsiClient::WarsApi* | [**get_wars_war_id_killmails**](docs/WarsApi.md#get_wars_war_id_killmails) | **GET** /wars/{war_id}/killmails/ | List kills for a war


## Documentation for Models

 - [EsiClient::DeleteCharactersCharacterIdMailLabelsLabelIdUnprocessableEntity](docs/DeleteCharactersCharacterIdMailLabelsLabelIdUnprocessableEntity.md)
 - [EsiClient::DeleteFleetsFleetIdMembersMemberIdNotFound](docs/DeleteFleetsFleetIdMembersMemberIdNotFound.md)
 - [EsiClient::DeleteFleetsFleetIdSquadsSquadIdNotFound](docs/DeleteFleetsFleetIdSquadsSquadIdNotFound.md)
 - [EsiClient::DeleteFleetsFleetIdWingsWingIdNotFound](docs/DeleteFleetsFleetIdWingsWingIdNotFound.md)
 - [EsiClient::Forbidden](docs/Forbidden.md)
 - [EsiClient::GetAlliancesAllianceIdIconsNotFound](docs/GetAlliancesAllianceIdIconsNotFound.md)
 - [EsiClient::GetAlliancesAllianceIdIconsOk](docs/GetAlliancesAllianceIdIconsOk.md)
 - [EsiClient::GetAlliancesAllianceIdNotFound](docs/GetAlliancesAllianceIdNotFound.md)
 - [EsiClient::GetAlliancesAllianceIdOk](docs/GetAlliancesAllianceIdOk.md)
 - [EsiClient::GetAlliancesNames200Ok](docs/GetAlliancesNames200Ok.md)
 - [EsiClient::GetCharactersCharacterIdAgentsResearch200Ok](docs/GetCharactersCharacterIdAgentsResearch200Ok.md)
 - [EsiClient::GetCharactersCharacterIdAssets200Ok](docs/GetCharactersCharacterIdAssets200Ok.md)
 - [EsiClient::GetCharactersCharacterIdAttributesOk](docs/GetCharactersCharacterIdAttributesOk.md)
 - [EsiClient::GetCharactersCharacterIdBlueprints200Ok](docs/GetCharactersCharacterIdBlueprints200Ok.md)
 - [EsiClient::GetCharactersCharacterIdBookmarks200Ok](docs/GetCharactersCharacterIdBookmarks200Ok.md)
 - [EsiClient::GetCharactersCharacterIdBookmarksCoordinates](docs/GetCharactersCharacterIdBookmarksCoordinates.md)
 - [EsiClient::GetCharactersCharacterIdBookmarksFolders200Ok](docs/GetCharactersCharacterIdBookmarksFolders200Ok.md)
 - [EsiClient::GetCharactersCharacterIdBookmarksItem](docs/GetCharactersCharacterIdBookmarksItem.md)
 - [EsiClient::GetCharactersCharacterIdBookmarksTarget](docs/GetCharactersCharacterIdBookmarksTarget.md)
 - [EsiClient::GetCharactersCharacterIdCalendar200Ok](docs/GetCharactersCharacterIdCalendar200Ok.md)
 - [EsiClient::GetCharactersCharacterIdCalendarEventIdOk](docs/GetCharactersCharacterIdCalendarEventIdOk.md)
 - [EsiClient::GetCharactersCharacterIdChatChannels200Ok](docs/GetCharactersCharacterIdChatChannels200Ok.md)
 - [EsiClient::GetCharactersCharacterIdChatChannelsAllowed](docs/GetCharactersCharacterIdChatChannelsAllowed.md)
 - [EsiClient::GetCharactersCharacterIdChatChannelsBlocked](docs/GetCharactersCharacterIdChatChannelsBlocked.md)
 - [EsiClient::GetCharactersCharacterIdChatChannelsMuted](docs/GetCharactersCharacterIdChatChannelsMuted.md)
 - [EsiClient::GetCharactersCharacterIdChatChannelsOperator](docs/GetCharactersCharacterIdChatChannelsOperator.md)
 - [EsiClient::GetCharactersCharacterIdClonesHomeLocation](docs/GetCharactersCharacterIdClonesHomeLocation.md)
 - [EsiClient::GetCharactersCharacterIdClonesJumpClone](docs/GetCharactersCharacterIdClonesJumpClone.md)
 - [EsiClient::GetCharactersCharacterIdClonesOk](docs/GetCharactersCharacterIdClonesOk.md)
 - [EsiClient::GetCharactersCharacterIdContacts200Ok](docs/GetCharactersCharacterIdContacts200Ok.md)
 - [EsiClient::GetCharactersCharacterIdContactsLabels200Ok](docs/GetCharactersCharacterIdContactsLabels200Ok.md)
 - [EsiClient::GetCharactersCharacterIdContracts200Ok](docs/GetCharactersCharacterIdContracts200Ok.md)
 - [EsiClient::GetCharactersCharacterIdContractsContractIdBids200Ok](docs/GetCharactersCharacterIdContractsContractIdBids200Ok.md)
 - [EsiClient::GetCharactersCharacterIdContractsContractIdItems200Ok](docs/GetCharactersCharacterIdContractsContractIdItems200Ok.md)
 - [EsiClient::GetCharactersCharacterIdCorporationhistory200Ok](docs/GetCharactersCharacterIdCorporationhistory200Ok.md)
 - [EsiClient::GetCharactersCharacterIdFittings200Ok](docs/GetCharactersCharacterIdFittings200Ok.md)
 - [EsiClient::GetCharactersCharacterIdFittingsItem](docs/GetCharactersCharacterIdFittingsItem.md)
 - [EsiClient::GetCharactersCharacterIdIndustryJobs200Ok](docs/GetCharactersCharacterIdIndustryJobs200Ok.md)
 - [EsiClient::GetCharactersCharacterIdKillmailsRecent200Ok](docs/GetCharactersCharacterIdKillmailsRecent200Ok.md)
 - [EsiClient::GetCharactersCharacterIdLocationOk](docs/GetCharactersCharacterIdLocationOk.md)
 - [EsiClient::GetCharactersCharacterIdLoyaltyPoints200Ok](docs/GetCharactersCharacterIdLoyaltyPoints200Ok.md)
 - [EsiClient::GetCharactersCharacterIdMail200Ok](docs/GetCharactersCharacterIdMail200Ok.md)
 - [EsiClient::GetCharactersCharacterIdMailLabelsLabel](docs/GetCharactersCharacterIdMailLabelsLabel.md)
 - [EsiClient::GetCharactersCharacterIdMailLabelsOk](docs/GetCharactersCharacterIdMailLabelsOk.md)
 - [EsiClient::GetCharactersCharacterIdMailLists200Ok](docs/GetCharactersCharacterIdMailLists200Ok.md)
 - [EsiClient::GetCharactersCharacterIdMailMailIdNotFound](docs/GetCharactersCharacterIdMailMailIdNotFound.md)
 - [EsiClient::GetCharactersCharacterIdMailMailIdOk](docs/GetCharactersCharacterIdMailMailIdOk.md)
 - [EsiClient::GetCharactersCharacterIdMailMailIdRecipient](docs/GetCharactersCharacterIdMailMailIdRecipient.md)
 - [EsiClient::GetCharactersCharacterIdMailRecipient](docs/GetCharactersCharacterIdMailRecipient.md)
 - [EsiClient::GetCharactersCharacterIdMedals200Ok](docs/GetCharactersCharacterIdMedals200Ok.md)
 - [EsiClient::GetCharactersCharacterIdMedalsGraphic](docs/GetCharactersCharacterIdMedalsGraphic.md)
 - [EsiClient::GetCharactersCharacterIdNotFound](docs/GetCharactersCharacterIdNotFound.md)
 - [EsiClient::GetCharactersCharacterIdOk](docs/GetCharactersCharacterIdOk.md)
 - [EsiClient::GetCharactersCharacterIdOpportunities200Ok](docs/GetCharactersCharacterIdOpportunities200Ok.md)
 - [EsiClient::GetCharactersCharacterIdOrders200Ok](docs/GetCharactersCharacterIdOrders200Ok.md)
 - [EsiClient::GetCharactersCharacterIdPlanets200Ok](docs/GetCharactersCharacterIdPlanets200Ok.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdExtractorDetails](docs/GetCharactersCharacterIdPlanetsPlanetIdExtractorDetails.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdFactoryDetails](docs/GetCharactersCharacterIdPlanetsPlanetIdFactoryDetails.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdHead](docs/GetCharactersCharacterIdPlanetsPlanetIdHead.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdLink](docs/GetCharactersCharacterIdPlanetsPlanetIdLink.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdNotFound](docs/GetCharactersCharacterIdPlanetsPlanetIdNotFound.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdOk](docs/GetCharactersCharacterIdPlanetsPlanetIdOk.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdPin](docs/GetCharactersCharacterIdPlanetsPlanetIdPin.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdRoute](docs/GetCharactersCharacterIdPlanetsPlanetIdRoute.md)
 - [EsiClient::GetCharactersCharacterIdPlanetsPlanetIdWaypoint](docs/GetCharactersCharacterIdPlanetsPlanetIdWaypoint.md)
 - [EsiClient::GetCharactersCharacterIdPortraitNotFound](docs/GetCharactersCharacterIdPortraitNotFound.md)
 - [EsiClient::GetCharactersCharacterIdPortraitOk](docs/GetCharactersCharacterIdPortraitOk.md)
 - [EsiClient::GetCharactersCharacterIdSearchOk](docs/GetCharactersCharacterIdSearchOk.md)
 - [EsiClient::GetCharactersCharacterIdShipOk](docs/GetCharactersCharacterIdShipOk.md)
 - [EsiClient::GetCharactersCharacterIdSkillqueue200Ok](docs/GetCharactersCharacterIdSkillqueue200Ok.md)
 - [EsiClient::GetCharactersCharacterIdSkillsOk](docs/GetCharactersCharacterIdSkillsOk.md)
 - [EsiClient::GetCharactersCharacterIdSkillsSkill](docs/GetCharactersCharacterIdSkillsSkill.md)
 - [EsiClient::GetCharactersCharacterIdStandings200Ok](docs/GetCharactersCharacterIdStandings200Ok.md)
 - [EsiClient::GetCharactersCharacterIdWalletJournal200Ok](docs/GetCharactersCharacterIdWalletJournal200Ok.md)
 - [EsiClient::GetCharactersCharacterIdWalletJournalExtraInfo](docs/GetCharactersCharacterIdWalletJournalExtraInfo.md)
 - [EsiClient::GetCharactersCharacterIdWalletTransactions200Ok](docs/GetCharactersCharacterIdWalletTransactions200Ok.md)
 - [EsiClient::GetCharactersCharacterIdWallets200Ok](docs/GetCharactersCharacterIdWallets200Ok.md)
 - [EsiClient::GetCharactersCharacterIdWalletsJournal200Ok](docs/GetCharactersCharacterIdWalletsJournal200Ok.md)
 - [EsiClient::GetCharactersNames200Ok](docs/GetCharactersNames200Ok.md)
 - [EsiClient::GetCorporationsCorporationIdAlliancehistory200Ok](docs/GetCorporationsCorporationIdAlliancehistory200Ok.md)
 - [EsiClient::GetCorporationsCorporationIdAlliancehistoryAlliance](docs/GetCorporationsCorporationIdAlliancehistoryAlliance.md)
 - [EsiClient::GetCorporationsCorporationIdIconsNotFound](docs/GetCorporationsCorporationIdIconsNotFound.md)
 - [EsiClient::GetCorporationsCorporationIdIconsOk](docs/GetCorporationsCorporationIdIconsOk.md)
 - [EsiClient::GetCorporationsCorporationIdMembers200Ok](docs/GetCorporationsCorporationIdMembers200Ok.md)
 - [EsiClient::GetCorporationsCorporationIdNotFound](docs/GetCorporationsCorporationIdNotFound.md)
 - [EsiClient::GetCorporationsCorporationIdOk](docs/GetCorporationsCorporationIdOk.md)
 - [EsiClient::GetCorporationsCorporationIdRoles200Ok](docs/GetCorporationsCorporationIdRoles200Ok.md)
 - [EsiClient::GetCorporationsCorporationIdStructures200Ok](docs/GetCorporationsCorporationIdStructures200Ok.md)
 - [EsiClient::GetCorporationsCorporationIdStructuresCurrentVul](docs/GetCorporationsCorporationIdStructuresCurrentVul.md)
 - [EsiClient::GetCorporationsCorporationIdStructuresNextVul](docs/GetCorporationsCorporationIdStructuresNextVul.md)
 - [EsiClient::GetCorporationsCorporationIdStructuresService](docs/GetCorporationsCorporationIdStructuresService.md)
 - [EsiClient::GetCorporationsNames200Ok](docs/GetCorporationsNames200Ok.md)
 - [EsiClient::GetDogmaAttributesAttributeIdNotFound](docs/GetDogmaAttributesAttributeIdNotFound.md)
 - [EsiClient::GetDogmaAttributesAttributeIdOk](docs/GetDogmaAttributesAttributeIdOk.md)
 - [EsiClient::GetDogmaEffectsEffectIdModifier](docs/GetDogmaEffectsEffectIdModifier.md)
 - [EsiClient::GetDogmaEffectsEffectIdNotFound](docs/GetDogmaEffectsEffectIdNotFound.md)
 - [EsiClient::GetDogmaEffectsEffectIdOk](docs/GetDogmaEffectsEffectIdOk.md)
 - [EsiClient::GetFleetsFleetIdMembers200Ok](docs/GetFleetsFleetIdMembers200Ok.md)
 - [EsiClient::GetFleetsFleetIdMembersNotFound](docs/GetFleetsFleetIdMembersNotFound.md)
 - [EsiClient::GetFleetsFleetIdNotFound](docs/GetFleetsFleetIdNotFound.md)
 - [EsiClient::GetFleetsFleetIdOk](docs/GetFleetsFleetIdOk.md)
 - [EsiClient::GetFleetsFleetIdWings200Ok](docs/GetFleetsFleetIdWings200Ok.md)
 - [EsiClient::GetFleetsFleetIdWingsNotFound](docs/GetFleetsFleetIdWingsNotFound.md)
 - [EsiClient::GetFleetsFleetIdWingsSquad](docs/GetFleetsFleetIdWingsSquad.md)
 - [EsiClient::GetIncursions200Ok](docs/GetIncursions200Ok.md)
 - [EsiClient::GetIndustryFacilities200Ok](docs/GetIndustryFacilities200Ok.md)
 - [EsiClient::GetIndustrySystems200Ok](docs/GetIndustrySystems200Ok.md)
 - [EsiClient::GetIndustrySystemsCostIndice](docs/GetIndustrySystemsCostIndice.md)
 - [EsiClient::GetInsurancePrices200Ok](docs/GetInsurancePrices200Ok.md)
 - [EsiClient::GetInsurancePricesLevel](docs/GetInsurancePricesLevel.md)
 - [EsiClient::GetKillmailsKillmailIdKillmailHashAttacker](docs/GetKillmailsKillmailIdKillmailHashAttacker.md)
 - [EsiClient::GetKillmailsKillmailIdKillmailHashItem](docs/GetKillmailsKillmailIdKillmailHashItem.md)
 - [EsiClient::GetKillmailsKillmailIdKillmailHashItem1](docs/GetKillmailsKillmailIdKillmailHashItem1.md)
 - [EsiClient::GetKillmailsKillmailIdKillmailHashOk](docs/GetKillmailsKillmailIdKillmailHashOk.md)
 - [EsiClient::GetKillmailsKillmailIdKillmailHashPosition](docs/GetKillmailsKillmailIdKillmailHashPosition.md)
 - [EsiClient::GetKillmailsKillmailIdKillmailHashUnprocessableEntity](docs/GetKillmailsKillmailIdKillmailHashUnprocessableEntity.md)
 - [EsiClient::GetKillmailsKillmailIdKillmailHashVictim](docs/GetKillmailsKillmailIdKillmailHashVictim.md)
 - [EsiClient::GetLoyaltyStoresCorporationIdOffers200Ok](docs/GetLoyaltyStoresCorporationIdOffers200Ok.md)
 - [EsiClient::GetLoyaltyStoresCorporationIdOffersRequiredItem](docs/GetLoyaltyStoresCorporationIdOffersRequiredItem.md)
 - [EsiClient::GetMarketsGroupsMarketGroupIdNotFound](docs/GetMarketsGroupsMarketGroupIdNotFound.md)
 - [EsiClient::GetMarketsGroupsMarketGroupIdOk](docs/GetMarketsGroupsMarketGroupIdOk.md)
 - [EsiClient::GetMarketsPrices200Ok](docs/GetMarketsPrices200Ok.md)
 - [EsiClient::GetMarketsRegionIdHistory200Ok](docs/GetMarketsRegionIdHistory200Ok.md)
 - [EsiClient::GetMarketsRegionIdHistoryUnprocessableEntity](docs/GetMarketsRegionIdHistoryUnprocessableEntity.md)
 - [EsiClient::GetMarketsRegionIdOrders200Ok](docs/GetMarketsRegionIdOrders200Ok.md)
 - [EsiClient::GetMarketsRegionIdOrdersUnprocessableEntity](docs/GetMarketsRegionIdOrdersUnprocessableEntity.md)
 - [EsiClient::GetMarketsStructuresStructureId200Ok](docs/GetMarketsStructuresStructureId200Ok.md)
 - [EsiClient::GetOpportunitiesGroupsGroupIdOk](docs/GetOpportunitiesGroupsGroupIdOk.md)
 - [EsiClient::GetOpportunitiesTasksTaskIdOk](docs/GetOpportunitiesTasksTaskIdOk.md)
 - [EsiClient::GetRouteOriginDestinationNotFound](docs/GetRouteOriginDestinationNotFound.md)
 - [EsiClient::GetSearchOk](docs/GetSearchOk.md)
 - [EsiClient::GetSovereigntyCampaigns200Ok](docs/GetSovereigntyCampaigns200Ok.md)
 - [EsiClient::GetSovereigntyCampaignsParticipant](docs/GetSovereigntyCampaignsParticipant.md)
 - [EsiClient::GetSovereigntyMap200Ok](docs/GetSovereigntyMap200Ok.md)
 - [EsiClient::GetSovereigntyStructures200Ok](docs/GetSovereigntyStructures200Ok.md)
 - [EsiClient::GetStatusOk](docs/GetStatusOk.md)
 - [EsiClient::GetUniverseBloodlines200Ok](docs/GetUniverseBloodlines200Ok.md)
 - [EsiClient::GetUniverseCategoriesCategoryIdNotFound](docs/GetUniverseCategoriesCategoryIdNotFound.md)
 - [EsiClient::GetUniverseCategoriesCategoryIdOk](docs/GetUniverseCategoriesCategoryIdOk.md)
 - [EsiClient::GetUniverseConstellationsConstellationIdNotFound](docs/GetUniverseConstellationsConstellationIdNotFound.md)
 - [EsiClient::GetUniverseConstellationsConstellationIdOk](docs/GetUniverseConstellationsConstellationIdOk.md)
 - [EsiClient::GetUniverseConstellationsConstellationIdPosition](docs/GetUniverseConstellationsConstellationIdPosition.md)
 - [EsiClient::GetUniverseFactions200Ok](docs/GetUniverseFactions200Ok.md)
 - [EsiClient::GetUniverseGraphicsGraphicIdNotFound](docs/GetUniverseGraphicsGraphicIdNotFound.md)
 - [EsiClient::GetUniverseGraphicsGraphicIdOk](docs/GetUniverseGraphicsGraphicIdOk.md)
 - [EsiClient::GetUniverseGroupsGroupIdNotFound](docs/GetUniverseGroupsGroupIdNotFound.md)
 - [EsiClient::GetUniverseGroupsGroupIdOk](docs/GetUniverseGroupsGroupIdOk.md)
 - [EsiClient::GetUniverseMoonsMoonIdNotFound](docs/GetUniverseMoonsMoonIdNotFound.md)
 - [EsiClient::GetUniverseMoonsMoonIdOk](docs/GetUniverseMoonsMoonIdOk.md)
 - [EsiClient::GetUniverseMoonsMoonIdPosition](docs/GetUniverseMoonsMoonIdPosition.md)
 - [EsiClient::GetUniversePlanetsPlanetIdNotFound](docs/GetUniversePlanetsPlanetIdNotFound.md)
 - [EsiClient::GetUniversePlanetsPlanetIdOk](docs/GetUniversePlanetsPlanetIdOk.md)
 - [EsiClient::GetUniversePlanetsPlanetIdPosition](docs/GetUniversePlanetsPlanetIdPosition.md)
 - [EsiClient::GetUniverseRaces200Ok](docs/GetUniverseRaces200Ok.md)
 - [EsiClient::GetUniverseRegionsRegionIdNotFound](docs/GetUniverseRegionsRegionIdNotFound.md)
 - [EsiClient::GetUniverseRegionsRegionIdOk](docs/GetUniverseRegionsRegionIdOk.md)
 - [EsiClient::GetUniverseSchematicsSchematicIdNotFound](docs/GetUniverseSchematicsSchematicIdNotFound.md)
 - [EsiClient::GetUniverseSchematicsSchematicIdOk](docs/GetUniverseSchematicsSchematicIdOk.md)
 - [EsiClient::GetUniverseStargatesStargateIdDestination](docs/GetUniverseStargatesStargateIdDestination.md)
 - [EsiClient::GetUniverseStargatesStargateIdNotFound](docs/GetUniverseStargatesStargateIdNotFound.md)
 - [EsiClient::GetUniverseStargatesStargateIdOk](docs/GetUniverseStargatesStargateIdOk.md)
 - [EsiClient::GetUniverseStargatesStargateIdPosition](docs/GetUniverseStargatesStargateIdPosition.md)
 - [EsiClient::GetUniverseStationsStationIdNotFound](docs/GetUniverseStationsStationIdNotFound.md)
 - [EsiClient::GetUniverseStationsStationIdOk](docs/GetUniverseStationsStationIdOk.md)
 - [EsiClient::GetUniverseStationsStationIdPosition](docs/GetUniverseStationsStationIdPosition.md)
 - [EsiClient::GetUniverseStructuresStructureIdNotFound](docs/GetUniverseStructuresStructureIdNotFound.md)
 - [EsiClient::GetUniverseStructuresStructureIdOk](docs/GetUniverseStructuresStructureIdOk.md)
 - [EsiClient::GetUniverseStructuresStructureIdPosition](docs/GetUniverseStructuresStructureIdPosition.md)
 - [EsiClient::GetUniverseSystemJumps200Ok](docs/GetUniverseSystemJumps200Ok.md)
 - [EsiClient::GetUniverseSystemKills200Ok](docs/GetUniverseSystemKills200Ok.md)
 - [EsiClient::GetUniverseSystemsSystemIdNotFound](docs/GetUniverseSystemsSystemIdNotFound.md)
 - [EsiClient::GetUniverseSystemsSystemIdOk](docs/GetUniverseSystemsSystemIdOk.md)
 - [EsiClient::GetUniverseSystemsSystemIdPlanet](docs/GetUniverseSystemsSystemIdPlanet.md)
 - [EsiClient::GetUniverseSystemsSystemIdPosition](docs/GetUniverseSystemsSystemIdPosition.md)
 - [EsiClient::GetUniverseTypesTypeIdDogmaAttribute](docs/GetUniverseTypesTypeIdDogmaAttribute.md)
 - [EsiClient::GetUniverseTypesTypeIdDogmaEffect](docs/GetUniverseTypesTypeIdDogmaEffect.md)
 - [EsiClient::GetUniverseTypesTypeIdNotFound](docs/GetUniverseTypesTypeIdNotFound.md)
 - [EsiClient::GetUniverseTypesTypeIdOk](docs/GetUniverseTypesTypeIdOk.md)
 - [EsiClient::GetWarsWarIdAggressor](docs/GetWarsWarIdAggressor.md)
 - [EsiClient::GetWarsWarIdAlly](docs/GetWarsWarIdAlly.md)
 - [EsiClient::GetWarsWarIdDefender](docs/GetWarsWarIdDefender.md)
 - [EsiClient::GetWarsWarIdKillmails200Ok](docs/GetWarsWarIdKillmails200Ok.md)
 - [EsiClient::GetWarsWarIdKillmailsUnprocessableEntity](docs/GetWarsWarIdKillmailsUnprocessableEntity.md)
 - [EsiClient::GetWarsWarIdOk](docs/GetWarsWarIdOk.md)
 - [EsiClient::GetWarsWarIdUnprocessableEntity](docs/GetWarsWarIdUnprocessableEntity.md)
 - [EsiClient::InternalServerError](docs/InternalServerError.md)
 - [EsiClient::PostCharactersAffiliation200Ok](docs/PostCharactersAffiliation200Ok.md)
 - [EsiClient::PostCharactersAffiliationUnprocessableEntity](docs/PostCharactersAffiliationUnprocessableEntity.md)
 - [EsiClient::PostCharactersCharacterIdCspaCharacters](docs/PostCharactersCharacterIdCspaCharacters.md)
 - [EsiClient::PostCharactersCharacterIdCspaCreated](docs/PostCharactersCharacterIdCspaCreated.md)
 - [EsiClient::PostCharactersCharacterIdFittingsCreated](docs/PostCharactersCharacterIdFittingsCreated.md)
 - [EsiClient::PostCharactersCharacterIdFittingsFitting](docs/PostCharactersCharacterIdFittingsFitting.md)
 - [EsiClient::PostCharactersCharacterIdFittingsItem](docs/PostCharactersCharacterIdFittingsItem.md)
 - [EsiClient::PostCharactersCharacterIdMailBadRequest](docs/PostCharactersCharacterIdMailBadRequest.md)
 - [EsiClient::PostCharactersCharacterIdMailLabelsLabel](docs/PostCharactersCharacterIdMailLabelsLabel.md)
 - [EsiClient::PostCharactersCharacterIdMailMail](docs/PostCharactersCharacterIdMailMail.md)
 - [EsiClient::PostCharactersCharacterIdMailRecipient](docs/PostCharactersCharacterIdMailRecipient.md)
 - [EsiClient::PostFleetsFleetIdMembersInvitation](docs/PostFleetsFleetIdMembersInvitation.md)
 - [EsiClient::PostFleetsFleetIdMembersNotFound](docs/PostFleetsFleetIdMembersNotFound.md)
 - [EsiClient::PostFleetsFleetIdMembersUnprocessableEntity](docs/PostFleetsFleetIdMembersUnprocessableEntity.md)
 - [EsiClient::PostFleetsFleetIdWingsCreated](docs/PostFleetsFleetIdWingsCreated.md)
 - [EsiClient::PostFleetsFleetIdWingsNotFound](docs/PostFleetsFleetIdWingsNotFound.md)
 - [EsiClient::PostFleetsFleetIdWingsWingIdSquadsCreated](docs/PostFleetsFleetIdWingsWingIdSquadsCreated.md)
 - [EsiClient::PostFleetsFleetIdWingsWingIdSquadsNotFound](docs/PostFleetsFleetIdWingsWingIdSquadsNotFound.md)
 - [EsiClient::PostUiOpenwindowNewmailNewMail](docs/PostUiOpenwindowNewmailNewMail.md)
 - [EsiClient::PostUiOpenwindowNewmailUnprocessableEntity](docs/PostUiOpenwindowNewmailUnprocessableEntity.md)
 - [EsiClient::PostUniverseNames200Ok](docs/PostUniverseNames200Ok.md)
 - [EsiClient::PostUniverseNamesNotFound](docs/PostUniverseNamesNotFound.md)
 - [EsiClient::PutCharactersCharacterIdCalendarEventIdResponse](docs/PutCharactersCharacterIdCalendarEventIdResponse.md)
 - [EsiClient::PutCharactersCharacterIdMailMailIdBadRequest](docs/PutCharactersCharacterIdMailMailIdBadRequest.md)
 - [EsiClient::PutCharactersCharacterIdMailMailIdContents](docs/PutCharactersCharacterIdMailMailIdContents.md)
 - [EsiClient::PutCorporationsCorporationIdStructuresStructureIdNewSchedule](docs/PutCorporationsCorporationIdStructuresStructureIdNewSchedule.md)
 - [EsiClient::PutFleetsFleetIdBadRequest](docs/PutFleetsFleetIdBadRequest.md)
 - [EsiClient::PutFleetsFleetIdMembersMemberIdMovement](docs/PutFleetsFleetIdMembersMemberIdMovement.md)
 - [EsiClient::PutFleetsFleetIdMembersMemberIdNotFound](docs/PutFleetsFleetIdMembersMemberIdNotFound.md)
 - [EsiClient::PutFleetsFleetIdMembersMemberIdUnprocessableEntity](docs/PutFleetsFleetIdMembersMemberIdUnprocessableEntity.md)
 - [EsiClient::PutFleetsFleetIdNewSettings](docs/PutFleetsFleetIdNewSettings.md)
 - [EsiClient::PutFleetsFleetIdNotFound](docs/PutFleetsFleetIdNotFound.md)
 - [EsiClient::PutFleetsFleetIdSquadsSquadIdNaming](docs/PutFleetsFleetIdSquadsSquadIdNaming.md)
 - [EsiClient::PutFleetsFleetIdSquadsSquadIdNotFound](docs/PutFleetsFleetIdSquadsSquadIdNotFound.md)
 - [EsiClient::PutFleetsFleetIdWingsWingIdNaming](docs/PutFleetsFleetIdWingsWingIdNaming.md)
 - [EsiClient::PutFleetsFleetIdWingsWingIdNotFound](docs/PutFleetsFleetIdWingsWingIdNotFound.md)


## Documentation for Authorization


### evesso

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://login.eveonline.com/oauth/authorize
- **Scopes**: 
  - esi-assets.read_assets.v1: EVE SSO scope esi-assets.read_assets.v1
  - esi-bookmarks.read_character_bookmarks.v1: EVE SSO scope esi-bookmarks.read_character_bookmarks.v1
  - esi-calendar.read_calendar_events.v1: EVE SSO scope esi-calendar.read_calendar_events.v1
  - esi-calendar.respond_calendar_events.v1: EVE SSO scope esi-calendar.respond_calendar_events.v1
  - esi-characters.read_agents_research.v1: EVE SSO scope esi-characters.read_agents_research.v1
  - esi-characters.read_blueprints.v1: EVE SSO scope esi-characters.read_blueprints.v1
  - esi-characters.read_chat_channels.v1: EVE SSO scope esi-characters.read_chat_channels.v1
  - esi-characters.read_contacts.v1: EVE SSO scope esi-characters.read_contacts.v1
  - esi-characters.read_corporation_roles.v1: EVE SSO scope esi-characters.read_corporation_roles.v1
  - esi-characters.read_loyalty.v1: EVE SSO scope esi-characters.read_loyalty.v1
  - esi-characters.read_medals.v1: EVE SSO scope esi-characters.read_medals.v1
  - esi-characters.read_opportunities.v1: EVE SSO scope esi-characters.read_opportunities.v1
  - esi-characters.read_standings.v1: EVE SSO scope esi-characters.read_standings.v1
  - esi-characters.write_contacts.v1: EVE SSO scope esi-characters.write_contacts.v1
  - esi-clones.read_clones.v1: EVE SSO scope esi-clones.read_clones.v1
  - esi-contracts.read_character_contracts.v1: EVE SSO scope esi-contracts.read_character_contracts.v1
  - esi-corporations.read_corporation_membership.v1: EVE SSO scope esi-corporations.read_corporation_membership.v1
  - esi-corporations.read_structures.v1: EVE SSO scope esi-corporations.read_structures.v1
  - esi-corporations.write_structures.v1: EVE SSO scope esi-corporations.write_structures.v1
  - esi-fittings.read_fittings.v1: EVE SSO scope esi-fittings.read_fittings.v1
  - esi-fittings.write_fittings.v1: EVE SSO scope esi-fittings.write_fittings.v1
  - esi-fleets.read_fleet.v1: EVE SSO scope esi-fleets.read_fleet.v1
  - esi-fleets.write_fleet.v1: EVE SSO scope esi-fleets.write_fleet.v1
  - esi-industry.read_character_jobs.v1: EVE SSO scope esi-industry.read_character_jobs.v1
  - esi-killmails.read_killmails.v1: EVE SSO scope esi-killmails.read_killmails.v1
  - esi-location.read_location.v1: EVE SSO scope esi-location.read_location.v1
  - esi-location.read_online.v1: EVE SSO scope esi-location.read_online.v1
  - esi-location.read_ship_type.v1: EVE SSO scope esi-location.read_ship_type.v1
  - esi-mail.organize_mail.v1: EVE SSO scope esi-mail.organize_mail.v1
  - esi-mail.read_mail.v1: EVE SSO scope esi-mail.read_mail.v1
  - esi-mail.send_mail.v1: EVE SSO scope esi-mail.send_mail.v1
  - esi-markets.read_character_orders.v1: EVE SSO scope esi-markets.read_character_orders.v1
  - esi-markets.structure_markets.v1: EVE SSO scope esi-markets.structure_markets.v1
  - esi-planets.manage_planets.v1: EVE SSO scope esi-planets.manage_planets.v1
  - esi-search.search_structures.v1: EVE SSO scope esi-search.search_structures.v1
  - esi-skills.read_skillqueue.v1: EVE SSO scope esi-skills.read_skillqueue.v1
  - esi-skills.read_skills.v1: EVE SSO scope esi-skills.read_skills.v1
  - esi-ui.open_window.v1: EVE SSO scope esi-ui.open_window.v1
  - esi-ui.write_waypoint.v1: EVE SSO scope esi-ui.write_waypoint.v1
  - esi-universe.read_structures.v1: EVE SSO scope esi-universe.read_structures.v1
  - esi-wallet.read_character_wallet.v1: EVE SSO scope esi-wallet.read_character_wallet.v1

